import { Component } from '@angular/core';
import { MdDialogRef } from '@angular/material';
import { FormGroup } from '@angular/forms';
var ComponentSettingsDialogComponent = (function () {
    function ComponentSettingsDialogComponent(dialogRef) {
        this.dialogRef = dialogRef;
        this.templateInputsData = {};
    }
    ComponentSettingsDialogComponent.prototype.ngOnInit = function () {
        this.formGroup = new FormGroup({});
        var self = this;
        this.formGroup.valueChanges
            .subscribe(function (value) {
            if (self.formDataCache === undefined) {
                self.formDataCache = {};
            }
            Object.assign(self.formDataCache, value);
        });
    };
    ComponentSettingsDialogComponent.prototype.ngOnDestroy = function () {
        this.formDataCache = undefined;
    };
    ComponentSettingsDialogComponent.prototype.registerFormControlComponent = function (comp) {
        if (comp) {
            var control = comp.getFormControl();
            if (control) {
                this.formGroup.addControl(comp.getPropertyName(), control);
            }
        }
    };
    ComponentSettingsDialogComponent.prototype.unregisterFormControlComponent = function (comp) {
        if (comp) {
            var control = comp.getFormControl();
            if (control) {
                this.formGroup.removeControl(comp.getPropertyName());
            }
        }
    };
    ComponentSettingsDialogComponent.prototype.setComponent = function (component) {
        this.component = component;
    };
    ComponentSettingsDialogComponent.prototype.setTemplateInputsData = function (inputsData) {
        var clonedInputsData = JSON.parse(JSON.stringify(inputsData));
        this.templateInputsData = clonedInputsData;
    };
    ComponentSettingsDialogComponent.prototype.save = function () {
        var _this = this;
        Object.keys(this.formGroup.controls).forEach(function (control) { return _this.formGroup.controls[control].markAsTouched(); });
        if (!this.formGroup.valid) {
            console.error('ERROR_MESSAGES.FORM_VALIDATION_ERROR');
            return;
        }
        var self = this;
        var configuredInputs = {};
        if (this.formDataCache) {
            var keys = Object.keys(this.formDataCache);
            keys.map(function (item) {
                var propertyValue = _this.formDataCache[item];
                if (self.templateInputsData[item].default !== propertyValue) {
                    configuredInputs[item] = propertyValue;
                    if (propertyValue !== undefined && typeof propertyValue !== 'string') {
                        configuredInputs[item] = propertyValue.toString();
                    }
                    if (self.templateInputsData[item].type === 'json') {
                        configuredInputs[item] = JSON.parse(propertyValue);
                    }
                }
            });
        }
        this.component.setConfiguredInputs(configuredInputs);
        this.dialogRef.close(this.component);
    };
    ComponentSettingsDialogComponent.prototype.cancel = function () {
        this.dialogRef.close(false);
    };
    ComponentSettingsDialogComponent.prototype.getInputData = function (inputName) {
        var inputData = this.templateInputsData[inputName];
        var configuredValue = this.component.getConfiguredInputValue(inputName);
        if (inputData.type === 'json') {
            configuredValue = JSON.stringify(configuredValue);
        }
        if (configuredValue !== undefined) {
            inputData.default = configuredValue;
        }
        return inputData;
    };
    ComponentSettingsDialogComponent.prototype.comparePropertyType = function (prop, type) {
        var propertyType = this.templateInputsData[prop].type;
        if (type === 'text') {
            return (propertyType === 'string' || propertyType === 'number' || propertyType === 'json');
        }
        return (propertyType === type);
    };
    return ComponentSettingsDialogComponent;
}());
export { ComponentSettingsDialogComponent };
ComponentSettingsDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'component-settings-dialog',
                inputs: [],
                template: "\n    <h1 md-dialog-title> {{ component.getDirective() }} </h1>\n    <md-dialog-content>\n      <form #settingsForm [formGroup]=\"formGroup\" fxLayout=\"column\">\n        <md-grid-list cols=\"2\" rowHeight=\"5:1\" gutterSize=\"16\">\n          <md-grid-tile *ngFor=\"let prop of component.getInputs()\" fxLayoutAlign=\"start center\">\n            <boolean-metadata fxFlexFill [property]=\"prop\" [data]=\"getInputData(prop)\" *ngIf=\"comparePropertyType(prop, 'boolean')\"></boolean-metadata>\n            <text-metadata fxFlexFill [property]=\"prop\" [data]=\"getInputData(prop)\" *ngIf=\"comparePropertyType(prop, 'text')\"></text-metadata>\n            <combo-metadata fxFlexFill [property]=\"prop\" [data]=\"getInputData(prop)\" *ngIf=\"comparePropertyType(prop, 'combo')\"></combo-metadata>\n          </md-grid-tile>\n        </md-grid-list>\n      </form>\n    </md-dialog-content>\n\n    <md-dialog-actions>\n      <button md-raised-button (click)=\"save()\">{{ 'SAVE' | oTranslate }}</button>\n      <button md-raised-button (click)=\"cancel()\">{{ 'CANCEL' | oTranslate }}</button>\n    </md-dialog-actions>\n  ",
                styles: ["\n    md-dialog-content{max-height:75vh}\n  "]
            },] },
];
ComponentSettingsDialogComponent.ctorParameters = function () { return [
    { type: MdDialogRef, },
]; };
//# sourceMappingURL=component-settings-dialog.component.js.map